@@ -27,11 +27,16 @@ stop_if_dot_args <- function(dot_args, msg = "") {
   if(length(dot_args)>1) {
     unams <- names(dot_args)[-1]
     uvals <- as.character(dot_args)[-1]
+    saw_blank <- any(nchar(uvals)<=0)
+    uvals <- sQuote(uvals, q=FALSE)
     unams[is.null(unams)] <- ""
     not_null <- nchar(unams)>0
     unams[not_null] <- paste0(unams[not_null], " = ")
     unams[!not_null] <- ""
     str <- paste(paste0(unams, uvals), collapse = ", ")
+    if(saw_blank) {
+      str <- paste(str, "(empty arguments can be caused by having exta commas in the function call)")
+    }
     stop(paste(msg, "unexpected arguments:", str),
          call. = FALSE)
   }
